import sys
from netCDF4 import Dataset

def ncdump(nc_fid, verb=True):
    """
    ncdump outputs dimensions, variables and their attribute information.
    The information is similar to that of NCAR's ncdump utility.
    nc_fid: netCDF4.Dataset
    verb: Boolean, whether or not to print the information
    """
    def print_ncattr(key):
        """
        Prints the NetCDF file attributes for a given key
        """
        try:
            print("\t\ttype:", repr(nc_fid.variables[key].dtype))
            for ncattr in nc_fid.variables[key].ncattrs():
                print('\t\t%s:' % ncattr, repr(nc_fid.variables[key].getncattr(ncattr)))
        except KeyError:
            print("\t\ttype:", type(nc_fid.getncattr(key)))
            for ncattr in nc_fid.ncattrs():
                print('\t\t%s:' % ncattr, repr(nc_fid.getncattr(ncattr)))

    # NetCDF global attributes
    if verb:
        print("NetCDF Global Attributes:")
        for nc_attr in nc_fid.ncattrs():
            print('\t%s:' % nc_attr, repr(nc_fid.getncattr(nc_attr)))
    nc_dims = [dim for dim in nc_fid.dimensions]  # list of NetCDF dimensions
    # Dimension shape information.
    if verb:
        print("NetCDF dimension information:")
        for dim in nc_dims:
            print("\tName:", dim)
            print("\t\tsize:", len(nc_fid.dimensions[dim]))
            print_ncattr(dim)
    # Variable information.
    nc_vars = [var for var in nc_fid.variables]  # list of NetCDF variables
    if verb:
        print("NetCDF variable information:")
        for var in nc_vars:
            if var not in nc_dims:
                print('\tName:', var)
                print("\t\tdimensions:", nc_fid.variables[var].dimensions)
                print("\t\tsize:", nc_fid.variables[var].size)
                print_ncattr(var)
    return nc_dims, nc_vars

if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Usage: python ncdump_like.py <netcdf-file>")
        sys.exit(1)
    nc_file = sys.argv[1]
    nc_fid = Dataset(nc_file, 'r')
    ncdump(nc_fid)
    nc_fid.close()
